==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/dataforms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>DataFormWidget</name>
    <message>
        <source>Page %1</source>
        <translation>Seite %1</translation>
    </message>
    <message>
        <source>The are %1 field(s) with invalid values:&lt;br&gt;</source>
        <translation>Es gibt %1 Feld(er) mit ungültigen Werten:&lt;br&gt;</translation>
    </message>
    <message>
        <source>Do you want to continue with invalid values?</source>
        <translation>Wollen Sie mit den ungültigen Werten fortfahren?</translation>
    </message>
</context>
<context>
    <name>DataForms</name>
    <message>
        <source>Data Forms</source>
        <translation>Daten Formulare</translation>
    </message>
    <message>
        <source>Data Forms Validation</source>
        <translation>Daten Formular Gültigkeit</translation>
    </message>
    <message>
        <source>Data Forms Layout</source>
        <translation>Daten Formular Layout</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Unsupported url scheme</source>
        <translation>Nicht unterstütztes URL Schema</translation>
    </message>
    <message>
        <source>Url load failed</source>
        <translation>Laden der URL fehlgeschlagen</translation>
    </message>
    <message>
        <source>Data Forms Manager</source>
        <translation>Daten Formular Manager</translation>
    </message>
    <message>
        <source>Allows other modules to process and display the form with the data intended for user</source>
        <translation>Erlaubt anderen Modulen das Auswerten und Anzeigen des Datenformular, welches für den Benutzer gedacht ist</translation>
    </message>
    <message>
        <source>Supports the processing and displaying of the forms with the data</source>
        <translation>Unterstützt das Auswerten und Anzeigen der Formulare mit den Daten</translation>
    </message>
    <message>
        <source>Supports the validating of the data entered in the form</source>
        <translation>Unterstützt die Validierung der im Formular eingegebenen Daten</translation>
    </message>
    <message>
        <source>Supports the layouting of the form, including the layout of form fields, pages and sections</source>
        <translation>Unterstützt das Gestalten eines Formularen, einschließlich des Layouts von Formularfeldern, -seiten und -sektionen</translation>
    </message>
</context>
<context>
    <name>DataMediaWidget</name>
    <message>
        <source>Unsupported media type</source>
        <translation>Nicht unterstützter Medientyp</translation>
    </message>
    <message>
        <source>Loading data...</source>
        <translation>Lade Daten...</translation>
    </message>
    <message>
        <source>Unsupported data format</source>
        <translation>Nicht unterstütztes Datenformat</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/dataforms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>DataFormWidget</name>
    <message>
        <source>Page %1</source>
        <translation>Seite %1</translation>
    </message>
    <message>
        <source>The are %1 field(s) with invalid values:&lt;br&gt;</source>
        <translation>Es gibt %1 Feld(er) mit ungültigen Werten:&lt;br&gt;</translation>
    </message>
    <message>
        <source>Do you want to continue with invalid values?</source>
        <translation>Wollen Sie mit den ungültigen Werten fortfahren?</translation>
    </message>
</context>
<context>
    <name>DataForms</name>
    <message>
        <source>Data Forms</source>
        <translation>Daten Formulare</translation>
    </message>
    <message>
        <source>Data Forms Validation</source>
        <translation>Daten Formular Überprüfung</translation>
    </message>
    <message>
        <source>Data Forms Layout</source>
        <translation>Daten Formular Layout</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Unsupported url scheme</source>
        <translation>Nicht unterstütztes URL Schema</translation>
    </message>
    <message>
        <source>Url load failed</source>
        <translation>Laden der URL fehlgeschlagen</translation>
    </message>
    <message>
        <source>Data Forms Manager</source>
        <translation>Daten Formular Manager</translation>
    </message>
    <message>
        <source>Allows other modules to process and display the form with the data intended for user</source>
        <translation>Erlaubt anderen Modulen das Auswerten und Anzeigen von Datenformular die für den Benutzer gedacht sind</translation>
    </message>
    <message>
        <source>Supports the processing and displaying of the forms with the data</source>
        <translation>Unterstützt das Auswerten und Anzeigen der Formulare mit den Daten</translation>
    </message>
    <message>
        <source>Supports the validating of the data entered in the form</source>
        <translation>Unterstützt die Überprüfung der im Formular eingegebenen Daten</translation>
    </message>
    <message>
        <source>Supports the layouting of the form, including the layout of form fields, pages and sections</source>
        <translation>Unterstützt das Gestalten eines Formulars, einschließlich des Layouts von Formularfeldern, -seiten und -sektionen</translation>
    </message>
</context>
<context>
    <name>DataMediaWidget</name>
    <message>
        <source>Unsupported media type</source>
        <translation>Nicht unterstützter Medientyp</translation>
    </message>
    <message>
        <source>Loading data...</source>
        <translation>Lade Daten...</translation>
    </message>
    <message>
        <source>Unsupported data format</source>
        <translation>Nicht unterstütztes Datenformat</translation>
    </message>
</context>
</TS>
